@@ -33,12 +33,15 @@
 #include <memory>
 
 #include <stdint.h>
+#include <string.h>
 
 // help out Eclipse's C++ parsing
 #ifndef INT32_MAX
 #define INT32_MAX 0x7FFFFFFF
 #endif
 
+class UndoRedoObserver;
+
 /**
  * Reads a space-separated list of strings and numbers. Strings are quoted,
  * quotes within strings can be escaped with backslashes.
@@ -401,7 +404,7 @@ class WriterParametersWrapper : public Parameters {
 	StringWriter writer;
 public:
 	/**
-	 * Construct a Parametes wrapper around another Parameters. Provides the
+	 * Construct a Parameters wrapper around another Parameters. Provides the
 	 * same parameters as this delegate, but writes out the command as it goes.
 	 * @param p The delegate.
 	 * @param name The name of the command (to write to the logger).
