@@ -21,7 +21,6 @@
 #include "videofactory.h"
 
 #include "src/domain/animation/animationimpl.h"
-#include "src/presentation/frontends/frontend.h"
 #include "src/technical/util.h"
 #include "src/technical/video/videoencoder.h"
 #include "src/domain/filenamevisitor.h"
@@ -30,9 +29,7 @@
 
 #include <unistd.h>
 #include <cstddef>
-#include <cstdlib>
 #include <cstring>
-#include <exception>
 #include <string>
 #include <sstream>
 #include <iomanip>
@@ -42,8 +39,8 @@
 
 using namespace std;
 
-VideoFactory::VideoFactory(const AnimationImpl *animation, Frontend *frontend)
-		: anim(animation), frontend(frontend) {
+VideoFactory::VideoFactory(const AnimationImpl *animation)
+		: anim(animation) {
 }
 
 
