@@ -584,21 +584,13 @@ Detta kan ställas in i inställningsmenyn.</translation>
         <location filename="../src/presentation/frontends/qtfrontend/importtab.cpp" line="110"/>
         <location filename="../src/presentation/frontends/qtfrontend/importtab.cpp" line="330"/>
         <source>Start daemon</source>
-        <translation type="unfinished"></translation>
+        <translation>Starta bakgrundsprocess</translation>
     </message>
     <message>
         <location filename="../src/presentation/frontends/qtfrontend/importtab.cpp" line="117"/>
         <location filename="../src/presentation/frontends/qtfrontend/importtab.cpp" line="331"/>
         <source>Stop daemon</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Start deamon</source>
-        <translation type="obsolete">Starta bakgrundsprocess</translation>
-    </message>
-    <message>
-        <source>Stop deamon</source>
-        <translation type="obsolete">Stoppa bakgrundsprocess</translation>
+        <translation>Stoppa bakgrundsprocess</translation>
     </message>
     <message>
         <location filename="../src/presentation/frontends/qtfrontend/importtab.cpp" line="59"/>
@@ -904,10 +896,6 @@ Detta kan ställas in i inställningsmenyn.</translation>
         <source>&lt;h4&gt;New&lt;/h4&gt; &lt;p&gt;Creates a &lt;em&gt;new&lt;/em&gt; project.&lt;/p&gt;</source>
         <translation>&lt;h4&gt;Ny&lt;/h&gt; &lt;p&gt;Skapar ett &lt;em&gt;nytt&lt;/em&gt; projekt.&lt;/p&gt;</translation>
     </message>
-    <message>
-        <source>&lt;h4&gt;Save&lt;/h4&gt; &lt;p&gt;&lt;em&gt;Saves&lt;/em&gt; the current animation as a Stopmotion project file. &lt;BR&gt;If this project has been saved before it will automaticly be saved to the previously selected file.&lt;/p&gt;</source>
-        <translation type="obsolete">&lt;h4&gt;Spara&lt;/h4&gt; &lt;p&gt;&lt;em&gt;Sparar&lt;/em&gt;animationen som Stopmotionprojektfil. &lt;BR&gt;Om det här projektet har sparats förut kommer det automatiskt sparas till den tidigare valda filen.&lt;/p&gt;</translation>
-    </message>
     <message>
         <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="608"/>
         <source>&lt;h4&gt;Save As&lt;/h4&gt; &lt;p&gt;&lt;em&gt;Saves&lt;/em&gt; the current animation as a Stopmotion project file.&lt;/p&gt;</source>
@@ -952,7 +940,7 @@ Detta kan ställas in i inställningsmenyn.</translation>
     <message>
         <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="598"/>
         <source>&lt;h4&gt;Save&lt;/h4&gt; &lt;p&gt;&lt;em&gt;Saves&lt;/em&gt; the current animation as a Stopmotion project file. &lt;BR&gt;If this project has been saved before it will automatically be saved to the previously selected file.&lt;/p&gt;</source>
-        <translation type="unfinished"></translation>
+        <translation>&lt;h4&gt;Spara&lt;/h4&gt; &lt;p&gt;&lt;em&gt;Sparar&lt;/em&gt;animationen som Stopmotionprojektfil. &lt;BR&gt;Om det här projektet har sparats förut kommer det automatiskt sparas till den tidigare valda filen.&lt;/p&gt;</translation>
     </message>
     <message>
         <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="604"/>
@@ -1207,14 +1195,6 @@ kontrollera inställningarna i inställngsmenyn?</translation>
         <source>vgrabbj VGA singleshot</source>
         <translation type="obsolete">vgrabbj VGA-enkelbild</translation>
     </message>
-    <message>
-        <source>vgrabbj VGA deamon</source>
-        <translation type="obsolete">vgrabbj VGA-damon</translation>
-    </message>
-    <message>
-        <source>Starts vgrabbj as a deamon. Pretty fast.</source>
-        <translation type="obsolete">Startar vgrabbj som bakgrundsprocess. Ganska snabb.</translation>
-    </message>
     <message>
         <location filename="../src/presentation/frontends/qtfrontend/qtfrontend.cpp" line="418"/>
         <source>Question</source>
@@ -1300,7 +1280,7 @@ kommer sparas i ~/.stopmotion/preferences.xml.OLD)</translation>
     <message>
         <location filename="../src/presentation/frontends/qtfrontend/qtfrontend.cpp" line="280"/>
         <source>Starts vgrabbj as a daemon. Pretty fast.</source>
-        <translation type="unfinished"></translation>
+        <translation>Startar vgrabbj som bakgrundsprocess. Ganska snabb.</translation>
     </message>
     <message>
         <location filename="../src/presentation/frontends/qtfrontend/qtfrontend.cpp" line="288"/>
@@ -1506,8 +1486,8 @@ to running the image grabbing as a daemon.</source>
     </message>
     <message>
         <source>Playback only currently works when running the grabber 
-as a deamon. Go to the preferences menu (CTRL+P) to switch 
-to running the image grabbing as a deamon.</source>
+as a daemon. Go to the preferences menu (CTRL+P) to switch
+to running the image grabbing as a daemon.</source>
         <translation type="obsolete">Uppspelning fungerar för tillfället bara när hämtaren körs
 som bakgrundsprocess. Gå till inställningsmenyn (CTRL+P) för att
 byta till att köra bildhämtningen som bakgrundsprocess.</translation>
