@@ -400,7 +400,7 @@
     </message>
     <message>
         <location filename="../src/presentation/frontends/qtfrontend/framepreferencesmenu.cpp" line="143"/>
-        <source>&lt;h4&gt;Sounds&lt;/h4&gt; &lt;p&gt;This lists shows all the sounds connected to this frame.&lt;/p&gt;&lt;p&gt;The sounds will begin playing when this frame is shown and play until they are done.&lt;/p&gt;</source>
+        <source>&lt;h4&gt;Sounds&lt;/h4&gt; &lt;p&gt;This list shows all the sounds connected to this frame.&lt;/p&gt;&lt;p&gt;The sounds will begin playing when this frame is shown and play until they are done.&lt;/p&gt;</source>
         <translation>&lt;h4&gt;Sesler&lt;/h4&gt; &lt;p&gt;Bu liste kareye bağlı tüm sesleri gösterir.&lt;/p&gt;&lt;p&gt;Sesler, karenin görünmesiyle birlikte sonuna dek çalar.&lt;/p&gt;</translation>
     </message>
 </context>
@@ -735,7 +735,7 @@ Seçenekler menüsünden yapabilirsiniz.</translation>
     </message>
     <message>
         <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="736"/>
-        <source>&lt;h4&gt;Frame number&lt;/h4&gt;&lt;p&gt;This area displays the numberof the currently selected frame&lt;/p&gt;</source>
+        <source>&lt;h4&gt;Frame number&lt;/h4&gt;&lt;p&gt;This area displays the number of the currently selected frame&lt;/p&gt;</source>
         <translation>&lt;h4&gt;Kare sırası&lt;/h4&gt;&lt;p&gt;Bu alanda seçili karenin sıra numarasını görebilirsiniz.&lt;/p&gt;</translation>
     </message>
     <message>
@@ -874,7 +874,7 @@ Seçenekler menüsünden yapabilirsiniz.</translation>
     </message>
     <message>
         <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="696"/>
-        <source>&lt;h4&gt;Configure Stopmotion&lt;/h4&gt; &lt;p&gt;This will opens a window where you can &lt;em&gt;configure&lt;/em&gt; Stopmotion with various input and output devices.&lt;/p&gt;</source>
+        <source>&lt;h4&gt;Configure Stopmotion&lt;/h4&gt; &lt;p&gt;This will open a window where you can &lt;em&gt;configure&lt;/em&gt; Stopmotion with various input and output devices.&lt;/p&gt;</source>
         <translation>&lt;h4&gt;Stopmotion yapılandırma&lt;/h4&gt; &lt;p&gt;Stopmotion için yakalama/aktarma aygıtlarını ve programlarını seçebileceğiniz bir &lt;em&gt;yapılandırma&lt;/em&gt; penceresi açar.&lt;/p&gt;</translation>
     </message>
     <message>
@@ -1325,7 +1325,7 @@ yeni bir kopyası bulundu. Bunu kullanmak ister misiniz?
     </message>
     <message>
         <location filename="../src/presentation/frontends/qtfrontend/toolsmenu.cpp" line="330"/>
-        <source>&lt;h4&gt;Loop animation (CTRL+L)&lt;/h4&gt; &lt;p&gt;With this button you can set whether you want the animation to play to the end, or to loop indefinetly.&lt;/p&gt;</source>
+        <source>&lt;h4&gt;Loop animation (CTRL+L)&lt;/h4&gt; &lt;p&gt;With this button you can set whether you want the animation to play to the end, or to loop indefinitely.&lt;/p&gt;</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
